@@ -1,3 +1,11 @@
+"""
+Tree-aggregated compositional model for statistical analysis of high-throughput sequencing data.
+
+For further reference, see:
+Ostner et al.: tascCODA: Bayesian Tree-Aggregated Analysis of Compositional Amplicon and Single-Cell Data
+
+:authors: Johannes Ostner
+"""
 
 import numpy as np
 import warnings
@@ -15,28 +23,28 @@ tfb = tfp.bijectors
 
 class TreeModelSSLasso(mod.CompositionalModel):
     """
-    Statistical model for single-cell differential composition analysis with specification of a reference cell type.
-    This is the standard scCODA model and recommenced for all uses.
+    Statistical model for tree-aggregated differential composition analysis (tascCODA, Ostner et al., 2021).
 
     The hierarchical formulation of the model for one sample is:
 
     .. math::
-         y|x &\\sim DirMult(a(x), \\bar{y}) \\\\
-         \\log(a(x)) &= \\alpha + x \\beta \\\\
-         \\alpha_k &\\sim N(0, 5) \\quad &\\forall k \\in [K] \\\\
-         \\beta_{d, \\hat{k}} &= 0 &\\forall d \\in [D]\\\\
-         \\beta_{d, k} &= \\tau_{d, k} \\tilde{\\beta}_{d, k} \\quad &\\forall d \\in [D], k \\in \\{[K] \\smallsetminus \\hat{k}\\} \\\\
-         \\tau_{d, k} &= \\frac{\\exp(t_{d, k})}{1+ \\exp(t_{d, k})} \\quad &\\forall d \\in [D], k \\in \\{[K] \\smallsetminus \\hat{k}\\} \\\\
-         \\frac{t_{d, k}}{50} &\\sim N(0, 1) \\quad &\\forall d \\in [D], k \\in \\{[K] \\smallsetminus \\hat{k}\\} \\\\
-         \\tilde{\\beta}_{d, k} &= (\\tilde{\\mu} + \\tilde{\\sigma}^2) \\cdot \\tilde{\\gamma}_{d, k} \\quad &\\forall d \\in [D], k \\in \\{[K] \\smallsetminus \\hat{k}\\} \\\\
-         \\tilde{\\mu} &\\sim N(0, 1) \\\\
-         \\tilde{\\sigma}^2 &\\sim HC(0, 1) \\\\
-         \\tilde{\\gamma}_{d, k} &\\sim N(0,1) \\quad &\\forall d \\in [D], k \\in \\{[K] \\smallsetminus \\hat{k}\\} \\\\
+         \\begin{align*}
+            Y_i &\\sim \\textrm{DirMult}(\\bar{Y}_i, \\textbf{a}(\\textbf{x})_i)\\\\
+            \\log(\\textbf{a}(X))_i &= \\alpha + X_{i, \\cdot} \\beta\\\\
+            \\alpha_j &\\sim \\mathcal{N}(0, 10) & \\forall j\\in[p]\\\\
+            \\beta &= \\hat{\\beta} A^T \\\\
+            \\hat{\\beta}_{l, k} &= 0 & \\forall k \\in \\hat{v}, l \\in [d]\\\\
+            \\hat{\\beta}_{l, k} &= \\theta \\tilde{\\beta}_{1, l, k} + (1- \\theta) \\tilde{\\beta}_{0, l, k} \\quad & \\forall k\\in\\{[v] \\smallsetminus \\hat{v}\\}, l \\in [d]\\\\
+            \\tilde{\\beta}_{m, l, k} &= \\sigma_{m, l, k} * b_{m, l, k} \\quad & \\forall k\\in\\{[v] \\smallsetminus \\hat{v}\\}, m \\in \\{0, 1\\}, l \\in [d]\\\\
+            \\sigma_{m, l, k} &\\sim \\textrm{Exp}(\\lambda_{m, l, k}^2/2) \\quad & \\forall k\\in\\{[v] \\smallsetminus \\hat{v}\\}, l \\in \\{0, 1\\}, l \\in [d]\\\\
+            b_{m, l, k} &\\sim N(0,1) \\quad & \\forall k\\in\\{[v] \\smallsetminus \\hat{v}\\}, l \\in \\{0, 1\\}, l \\in [d]\\\\
+            \\theta &\\sim \\textrm{Beta}(1, \\frac{1}{|\\{[v] \\smallsetminus \\hat{v}\\}|})
+        \\end{align*}
 
-    with y being the cell counts and x the covariates.
+    with Y being the cell counts, X the covariates, and v the set of nodes of the underlying tree structure.
 
-    For further information, see `scCODA: A Bayesian model for compositional single-cell data analysis`
-    (Büttner, Ostner et al., 2020)
+    For further information, see `tascCODA: Bayesian Tree-Aggregated Analysis of Compositional Amplicon and Single-Cell Data`
+    (Ostner et al., 2021)
 
     """
 
@@ -54,10 +62,22 @@ class TreeModelSSLasso(mod.CompositionalModel):
         Constructor of model class. Defines model structure, log-probability function, parameter names,
         and MCMC starting values.
 
+        This class is generated when calling `tasccoda.tree_ana.CompositionalAnalysisTree`
+
         Parameters
         ----------
-        reference_cell_type
-            Index of reference cell type (column in count data matrix)
+        node_names
+            List of names of the internal nodes of the tree
+        reference_nodes
+            List of indices that serve as reference nodes (one leaf and its ancestors)
+        A
+            Ancestor matrix
+        T
+            Number of nodes in the tree, excluding the root node
+        reg
+            Indicator for regularization scheme. Default: "scaled_3". Other schemes are only available for legacy reasons and might be discontinued
+        pen_args
+            Dictionary with penalty arguments. With `reg="scaled_3"`, the parameters phi, lambda_1, lambda_0 can be set here
         args
             arguments passed to top-level class
         kwargs
@@ -121,8 +141,10 @@ class TreeModelSSLasso(mod.CompositionalModel):
         alpha_size = [self.K]
         beta_nobl_size = [self.D, self.T-self.n_ref_nodes]
 
+        # Size of inferred parameter matrix
         d = self.D * (self.T-self.n_ref_nodes)
 
+        # Define model
         Root = tfd.JointDistributionCoroutine.Root
 
         def model():
@@ -203,6 +225,7 @@ class TreeModelSSLasso(mod.CompositionalModel):
 
         self.model_struct = tfd.JointDistributionCoroutine(model)
 
+        # Target log-prob function
         @tf.function(experimental_compile=True, autograph=False)
         def target_log_prob_fn(*args):
             log_prob = self.model_struct.log_prob(list(args) + [tf.cast(self.y, dtype)])
@@ -230,7 +253,6 @@ class TreeModelSSLasso(mod.CompositionalModel):
             tfb.Identity(),
         ]
 
-
     # Calculate predicted cell counts (for analysis purposes)
     def get_y_hat(
             self,
@@ -471,7 +493,7 @@ class TreeModelSSLasso(mod.CompositionalModel):
                 'diverging': (pkr.inner_results.inner_results.inner_results.log_accept_ratio < -1000.),
                 "log_acc_ratio": pkr.inner_results.inner_results.inner_results.log_accept_ratio,
                 'is_accepted': pkr.inner_results.inner_results.inner_results.is_accepted,
-                'step_size': tf.exp(pkr.inner_results.log_averaging_step[0]),
+                'step_size': tf.exp(pkr.inner_results.log_averaging_step),
             }
 
         # HMC sampling
@@ -609,6 +631,26 @@ class TreeModelSSLasso(mod.CompositionalModel):
 
     def make_result(self, states_burnin, sample_stats, sampling_stats):
 
+        """
+        Result object generating function. Transforms chain states to result object.
+
+        Parameters
+        ----------
+        states_burnin
+            MCMC chain states after burn-in removal
+        sample_stats
+            Dict with information about the MCMC samples
+        sampling_stats
+            Dict with information about the sampling process
+
+        Returns
+        -------
+        result object
+
+        result
+            Compositional analysis result
+        """
+
         params = dict(zip(self.param_names, states_burnin))
 
         # Result object generation setup
